=========
pylexique
=========


.. image:: https://img.shields.io/pypi/v/pylexique.svg
        :target: https://pypi.python.org/pypi/pylexique


.. image:: https://readthedocs.org/projects/pylexique/badge/?version=latest
        :target: https://pylexique.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/SekouDiaoNlp/pylexique/shield.svg
     :target: https://pyup.io/repos/github/SekouDiaoNlp/pylexique/
     :alt: Updates



Pylexique is a Python wrapper around Lexique83_.

It allows to extract lexical information from more than 140 000 French words in an Object Oriented way.


* Free software: MIT license
* Documentation: https://pylexique.readthedocs.io.


Features
--------

* Extract oll lexical information from a French  word.
* Easy to use Api.
* Easily integrate pylexique in your own projects as an imported library.
* Can be used as a command line tool.

Credits
-------

Main developer SekouDiaoNlp_.

Lexique38x has been developed by:

.. code:: bibtex

    @article{npbf04,
    author = {New, B. and Pallier, C. and Brysbaert, M. and Ferrand, L.},
    journal = {ehavior Research Methods, Instruments, & Computers},
    number = {3},
    pages = {516-524},
    title = {Lexique 2 : A New French Lexical Database},
    volume = {36},
    year = {2004},
    eprint = {http://www.lexique.org/?page_id=294},
    }

.. code:: bibtex

    @article{npfm01,
    author = {New, B. and Pallier, C. and Ferrand, L. and Matos, R.},
    journal = {L'Ann{\'e}e Pschologique},
    number = {447-462},
    pages = {1396-2},
    title = {Une base de donn{\'e}es lexicales du fran\c{c}ais contemporain sur internet: LEXIQUE},
    volume = {101},
    year = {2001},
    }

.. _Lexique83: http://www.lexique.org/
.. _SekouDiaoNlp: https://github.com/SekouDiaoNlp
